@@ -41,7 +41,7 @@ import shutil
 import io
 from bmaptools import BmapCreate, BmapCopy, BmapHelpers, TransRead
 
-VERSION = "3.5"
+VERSION = "3.6"
 
 log = logging.getLogger()  # pylint: disable=C0103
 
@@ -384,13 +384,11 @@ def open_files(args):
     (bmap_obj, bmap_path) = find_and_open_bmap(args)
 
     if bmap_path == args.image:
-        # Most probably the specified the bmap file instead of the image file
-        # by mistake.
-        log.warning("image has the same path as the bmap file, dropping bmap")
+        # Most probably the user specified the bmap file instead of the image
+        # file by mistake.
         bmap_obj.close()
-        bmap_obj = None
-        bmap_path = None
-        args.nobmap = True
+        error_out("Make sure you are writing your image and not the bmap file "
+                  "(you specified the same path for them)")
 
     # If the destination file is under "/dev", but does not exist, print a
     # warning. This is done in order to be more user-friendly, because
@@ -484,6 +482,9 @@ def copy_command(args):
                  % (os.path.basename(args.image), dest_str,
                     os.path.basename(bmap_path)))
 
+    if args.psplash_pipe:
+        writer.set_psplash_pipe(args.psplash_pipe)
+
     try:
         try:
             writer.copy(False, not args.no_verify)
@@ -642,6 +643,10 @@ def parse_arguments():
     text = "do not verify the data checksum while writing"
     parser_copy.add_argument("--no-verify", action="store_true", help=text)
 
+    # The --psplash-pipe option
+    text = "write progress to a psplash pipe"
+    parser_copy.add_argument("--psplash-pipe", help=text)
+
     return parser.parse_args()
 
 
