@@ -100,6 +100,11 @@ class _FilemapBase(object):
             raise Error("cannot synchronize image file '%s': %s "
                         % (self._image_path, err.strerror))
 
+        if not BmapHelpers.is_compatible_file_system(self._image_path):
+            fstype = BmapHelpers.get_file_system_type(self._image_path)
+            raise Error("image file on incompatible file system '%s': '%s': see docs for fix"
+                        % (self._image_path, fstype))
+
         _log.debug("opened image \"%s\"" % self._image_path)
         _log.debug("block size %d, blocks count %d, image size %d"
                    % (self.block_size, self.blocks_cnt, self.image_size))
@@ -476,7 +481,11 @@ class FilemapFiemap(_FilemapBase):
         _log.debug("FilemapFiemap: get_mapped_ranges(%d,  %d(%d))"
                    % (start, count, start + count - 1))
         iterator = self._do_get_mapped_ranges(start, count)
-        first_prev, last_prev = next(iterator)
+
+        try:
+            first_prev, last_prev = next(iterator)
+        except StopIteration:
+            return
 
         for first, last in iterator:
             if last_prev == first - 1:
