@@ -78,24 +78,23 @@ new_ver="$1"; shift
 printf "%s" "$new_ver" | egrep -q -x '[[:digit:]]+\.[[:digit:]]+' ||
         fatal "please, provide new version in X.Y format"
 
-# Make sure that the current branch is 'devel'
+# Make sure that the current branch is 'master'
 current_branch="$(git branch | sed -n -e '/^*/ s/^* //p')"
-if [ "$current_branch" != "devel" ]; then
-	fatal "current branch is '$current_branch' but must be 'devel'"
+if [ "$current_branch" != "master" ]; then
+	fatal "current branch is '$current_branch' but must be 'master'"
 fi
 
+# Make sure the git index is up-to-date
+[ -z "$(git status --porcelain)" ] || fatal "git index is not up-to-date"
+
 # Remind the maintainer about various important things
 ask_question "Did you update the docs/RELEASE_NOTES file"
 ask_question "Did you update the docs/README file"
 ask_question "Did you update the man page"
-ask_question "Did you update documentation on tizen.org"
 ask_question "Did you update tests: test-data and oldcodebase"
 
-# Make sure the git index is up-to-date
-[ -z "$(git status --porcelain)" ] || fatal "git index is not up-to-date"
-
-# Change the version in the 'bmaptool' file
-sed -i -e "s/^VERSION = \"[0-9]\+\.[0-9]\+\"$/VERSION = \"$new_ver\"/" bmaptool
+# Change the version in the 'bmaptools/CLI.py' file
+sed -i -e "s/^VERSION = \"[0-9]\+\.[0-9]\+\"$/VERSION = \"$new_ver\"/" bmaptools/CLI.py
 # Sed the version in the RPM spec file
 sed -i -e "s/^Version: [0-9]\+\.[0-9]\+$/Version: $new_ver/" packaging/bmap-tools.spec
 # Remove the "rc_num" macro from the RPM spec file to make sure we do not have
@@ -148,59 +147,23 @@ release_name="bmap-tools-$new_ver"
 printf "%s\n" "Signing tag $tag_name"
 git tag -m "$release_name" -s "$tag_name"
 
-# Prepare a signed tarball
-git archive --format=tar --prefix="$release_name/" "$tag_name" | \
-        gzip > "$outdir/$release_name.tgz"
-printf "%s\n" "Signing the tarball"
-gpg -o "$outdir/$release_name.tgz.asc" --detach-sign -a "$outdir/$release_name.tgz"
-
 # Get the name of the release branch corresponding to this version
 release_branch="release-$(printf "%s" "$new_ver" | sed -e 's/\(.*\)\..*/\1.0/')"
 
 cat <<EOF
 To finish the release:
   1. push the $tag_name tag out
-  2. copy the tarball to ftp.infradead.org
-  3. update the $release_branch with the contents of the 'devel' branch
-  4. point the master branch to the updated $release_branch branch
-  5. push the devel, master and the $release_branch branches out
-  6. (a bit later) push to the public tree and announce the new release
-     in the public mailing list
+  2. update the $release_branch with the contents of the 'master' branch
+  3. point the master branch to the updated $release_branch branch
+  4. push the master and $release_branch branches out
 
 The commands would be:
 
 #1
 git push origin $tag_name
 #2
-scp "$outdir/$release_name.tgz" "$outdir/$release_name.tgz.asc" casper.infradead.org:/var/ftp/pub/bmap-tools/
+git branch -f $release_branch master
 #3
-git branch -f $release_branch devel
-#4
-git branch -f master $release_branch
-#5
-git push origin devel:devel
 git push origin master:master
 git push origin $release_branch:$release_branch
-#6
-git push public $tag_name
-git push public devel:devel
-git push public master:master
-git push public $release_branch:$release_branch
-git send-email --suppress-cc=all --from "Artem Bityutskiy <dedekind1@gmail.com>" --to bmap-tools@lists.infradead.org /proc/self/fd/0 <<END_OF_EMAIL
-Subject: Announcement: $release_name is out!
-
-Bmap-tools version $new_ver is out!
-
-Release notes: http://git.infradead.org/users/dedekind/bmap-tools.git/blob/refs/heads/$release_branch:/docs/RELEASE_NOTES
-Tarball: ftp://ftp.infradead.org/pub/bmap-tools/
-
-Packages for various distributions are available here:
-http://download.tizen.org/tools/pre-release/
-
-At some later point they will be propagated to here:
-http://download.tizen.org/tools/latest-release/
-
---
-Artem Bityutskiy
-END_OF_EMAIL
 EOF
